# Publishing Custom Reports on the SAP LeanIX Store
### On this page
  * [Getting Started with the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#getting-started-with-the-sap-leanix-store)
  * [Publishing Process](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#publishing-process)
  * [Review Criteria](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#review-criteria)
  * [Step 1: Register as a Publisher](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#step-1:-register-as-a-publisher)
  * [Step 2: Create a Report](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#step-2:-create-a-report)
  * [Step 3: Initiate the Review Process](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#step-3:-initiate-the-review-process)
  * [Step 4: Create New Report Versions](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store#step-4:-create-new-report-versions)


Learn how the SAP LeanIX Store works and how to publish your custom reports.
